"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = jsonSchemaToReactSchema;
function jsonSchemaToReactSchema(jsonSchema) {
  try {
    var result = createReactSchemaSkeleton(jsonSchema.title);
    var properties = jsonSchema.type === 'array' ? jsonSchema.items.properties : jsonSchema.properties;
    result.questionSets[0].questions = createQuestions(properties, jsonSchema.required);
    return result;
  } catch (ex) {
    console.log(ex);
    return null;
  }
}

function createReactSchemaSkeleton(title) {
  return {
    "showErrorSummary": true,
    "summaryErrorMessage": "There are errors in your input. Please correct them and submit again.",
    "classes": {
      "questionPanelHeaderContainer": "question-panel-header",
      "questionSetHeaderContainer": "question-set-header",
      "errorContainer": "error-container",
      "input": "form-control flat",
      "question": "form-group",
      "backButton": "pull-left",
      "errorMessage": "error-input",
      "buttonBar": "button-bar",
      "radioListItem": "radio"
    },
    "formPanels": [{
      "index": 1,
      "panelId": "my-panel"
    }],
    "questionPanels": [{
      "panelId": "my-panel",
      "disableDefaultButton": false,
      "panelHeader": title,
      "action": {
        "default": {
          "action": "SUBMIT"
        }
      },
      "button": {
        "text": "Send"
      },
      "questionSets": [{
        "index": 1,
        "questionSetId": "question-set-1"
      }]
    }],
    "questionSets": [{
      "questionSetId": "question-set-1",
      "questions": []
    }]
  };
}

function createQuestions(properties, requiredItems) {
  var result = [];
  var requiredQuestions = requiredItems || [];
  var keys = Object.keys(properties);
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = keys[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var key = _step.value;

      var isRequired = requiredItems && requiredItems.indexOf(key) >= 0;
      var question = createQuestion(key, properties[key], isRequired);
      result.push(question);
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator.return) {
        _iterator.return();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return result;
}

function createQuestion(key, item, isRequired) {
  var description = item.description || key;

  var result = {
    "questionId": key,
    "input": {
      "name": key,
      "type": "materialTextField",
      "required": Boolean(isRequired),
      "props": {
        "fullWidth": true,
        "hintText": description,
        "floatingLabelText": description
      }
    }
  };

  if (item.type === 'string') {
    result.input.type = 'materialTextField';
  } else if (item.type === 'integer' || item.type === 'number') {
    result.input.type = 'materialTextField';
    result.input.props.type = 'number';
  } else if (item.type === 'array') {
    result.input.type = 'ArrayInput';
    var elements = { questions: [] };
    elements.questions = createQuestions(item.items.properties, item.items.required);
    result.input.props.elements = elements;
  } else {
    console.log("############## unknown: ", item);
    result.input.type = null;
  }
  return result;
}