'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = reactSchemaToJsonSchema;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var _require = require('lodash'),
    cloneDeep = _require.cloneDeep,
    forOwn = _require.forOwn,
    isUndefined = _require.isUndefined,
    isString = _require.isString,
    isObject = _require.isObject,
    isNull = _require.isNull,
    isEmpty = _require.isEmpty,
    isNaN = _require.isNaN,
    isArray = _require.isArray,
    pull = _require.pull;

var reactToModelEnums = require('./enums/react-to-model-enums');

var defaultTypes = Object.keys(reactToModelEnums.type);

function reactSchemaToJsonSchema(schema) {
  var result = {};
  result.title = schema.name;
  result.type = 'object';
  var questions = [];
  schema.questionSets.map(function (questionSet) {
    questions = questions.concat(questionSet.questions);
  });
  makeSubSchema(questions, result);
  return pruneEmpty(result);
};

function makeProperty(question) {
  var property = _defineProperty({}, question.questionId, {});
  if (defaultTypes.includes(question.input.props.type)) {
    property[question.questionId].type = reactToModelEnums.type[question.input.props.type];
  } else {
    property[question.questionId].type = [question.input.props.type];
  }
  if (reactToModelEnums.type[question.input.props.type] === 'object' && question.input.props.elements && question.input.props.elements.questions) {
    [question.questionId].properties = makeSubSchema(question.input.props.elements.questions, property[question.questionId]);
  }
  property[question.questionId].enum = getEnums(question);
  return property;
}

function makeSubSchema(questions, result) {
  result.properties = {};
  questions.map(function (question) {
    result.properties = Object.assign(result.properties, makeProperty(question));
    if (isRequired(question)) {
      if (Array.isArray(result.required)) {
        result.required.push(question.questionId);
      } else {
        result.required = [];
        result.required.push(question.questionId);
      }
    }
  });
}

function isRequired(question) {
  return !!(question && question.input && question.input.required);
}

function getEnums(question) {
  return question.input.props.options && question.input.props.options.map(function (option) {
    return option.value;
  });
}

function pruneEmpty(obj) {
  return function prune(current) {
    forOwn(current, function (value, key) {
      if (isUndefined(value) || isNull(value) || isNaN(value) || isString(value) && isEmpty(value) || isObject(value) && isEmpty(prune(value))) {

        delete current[key];
      }
    });
    // remove any leftover undefined values from the delete
    // operation on an array
    if (isArray(current)) pull(current, undefined);

    return current;
  }(cloneDeep(obj)); // Do not modify the original object, create a clone instead
}