const {
  cloneDeep,
  forOwn,
  isUndefined,
  isString,
  isObject,
  isNull,
  isEmpty,
  isNaN,
  isArray,
  pull
} = require('lodash');

const reactToModelEnums = require('./enums/react-to-model-enums');

const defaultTypes = Object.keys(reactToModelEnums.type);

export default function reactSchemaToJsonSchema(schema) {
  const result = {};
  result.title = schema.name;
  result.type = 'object';
  let questions = [];
  schema.questionSets.map(questionSet => {
    questions = questions.concat(questionSet.questions);
  });
  makeSubSchema(questions, result);
  return pruneEmpty(result);
};

function makeProperty(question) {
  const property = {
    [question.questionId]: {}
  };
  if (defaultTypes.includes(question.input.props.type)) {
    property[question.questionId].type = reactToModelEnums.type[question.input.props.type];
  } else {
    property[question.questionId].type = [question.input.props.type];
  }
  if (reactToModelEnums.type[question.input.props.type] === 'object' && question.input.props.elements && question.input.props.elements.questions) {
    [question.questionId].properties = makeSubSchema(question.input.props.elements.questions, property[question.questionId])
  }
  property[question.questionId].enum = getEnums(question);
  return property;
}

function makeSubSchema(questions, result) {
  result.properties = {};
  questions.map(question => {
    result.properties = Object.assign(result.properties, makeProperty(question));
    if(isRequired(question)){
        if(Array.isArray(result.required)){
          result.required.push(question.questionId)
        }else{
          result.required = [];
          result.required.push(question.questionId)
        }
    }
  });
}

function isRequired (question){
  return !!(question && question.input && question.input.required);
}

function getEnums(question) {
  return question.input.props.options && question.input.props.options.map(option => option.value);
}

function pruneEmpty(obj) {
  return function prune(current) {
    forOwn(current, function(value, key) {
      if (isUndefined(value) || isNull(value) || isNaN(value) || (isString(value) && isEmpty(value)) || (isObject(value) && isEmpty(prune(value)))) {

        delete current[key];
      }
    });
    // remove any leftover undefined values from the delete
    // operation on an array
    if (isArray(current))
      pull(current, undefined);

    return current;

  }(cloneDeep(obj)); // Do not modify the original object, create a clone instead
}
