export default function jsonSchemaToReactSchema(jsonSchema) {
  try{
    let result = createReactSchemaSkeleton(jsonSchema.title);
    const properties = jsonSchema.type === 'array' ? jsonSchema.items.properties : jsonSchema.properties;
    result.questionSets[0].questions = createQuestions(properties, jsonSchema.required);
    return result;
  } catch(ex){
    console.log(ex);
    return null;
  }
}

function createReactSchemaSkeleton(title) {
  return {
    "showErrorSummary":true,
    "summaryErrorMessage": "There are errors in your input. Please correct them and submit again.",
    "classes":{
      "questionPanelHeaderContainer":"question-panel-header",
      "questionSetHeaderContainer":"question-set-header",
      "errorContainer":"error-container",
      "input":"form-control flat",
      "question":"form-group",
      "backButton":"pull-left",
      "errorMessage":"error-input",
      "buttonBar":"button-bar",
      "radioListItem":"radio"
    },
    "formPanels":[
      {
        "index":1,
        "panelId":"my-panel"
      }
    ],
    "questionPanels":[
      {
        "panelId":"my-panel",
        "disableDefaultButton":false,
        "panelHeader":title,
        "action":{
          "default":{
            "action":"SUBMIT"
          }
        },
        "button":{
          "text":"Send"
        },
        "questionSets":[
          {
            "index":1,
            "questionSetId":"question-set-1"
          }
        ]
      }
    ],
    "questionSets":[
      {
        "questionSetId":"question-set-1",
        "questions":[
        ]
      }
    ]
  }
}

function createQuestions(properties, requiredItems) {
  let result = [];
  const requiredQuestions = requiredItems || [];
  const keys = Object.keys(properties);
  for (const key of keys) {
    const isRequired = requiredItems && requiredItems.indexOf(key) >= 0;
    const question = createQuestion(key, properties[key], isRequired);
    result.push(question);
  }
  return result;
}

function createQuestion(key, item, isRequired) {
  const description = item.description || key;

  let result = {
      "questionId":key,
      "input":{
        "name":key,
        "type":"materialTextField",
        "required":Boolean(isRequired),
        "props":{
          "fullWidth":true,
          "hintText":description,
          "floatingLabelText":description
        }
      }
  };

  if(item.type === 'string') {
    result.input.type = 'materialTextField';
  } else if(item.type === 'integer' || item.type === 'number') {
    result.input.type = 'materialTextField';
    result.input.props.type = 'number';
  } else if(item.type === 'array') {
    result.input.type = 'ArrayInput';
    const elements = {questions:[]};
    elements.questions = createQuestions(item.items.properties, item.items.required);
    result.input.props.elements = elements;

  } else {
    console.log("############## unknown: ",item);
    result.input.type = null;
  }
  return result;

}
